@@ -119,8 +119,8 @@ class Locale:
                 'xkblayout':'us,it',
                 'language':'it',
         },
-    'nl_BE' : {
-                'name':__('Nederland'),
+    'nl_NL' : {
+                'name':__('Dutch'),
                 'locale':'nl_BE.UTF-8',
                 'keymap':'nl',
                 'dumpkeys_charset':'',
@@ -128,6 +128,15 @@ class Locale:
                 'xkblayout':'us,nl',
                 'language':'nl',
         },
+    'nl_BE' : {
+                'name':__('Belgian Dutch (Flemish)'),
+                'locale':'nl_BE.UTF-8',
+                'keymap':'nl',
+                'dumpkeys_charset':'',
+                'consolefont':'lat9w-16',
+                'xkblayout':'us,nl',
+                'language':'nl_BE',
+        },
     'nn_NO' : {
                 'name':__('Norwegian'),
                 'locale':'nn_NO.UTF-8',
@@ -330,7 +339,7 @@ class VariableOsLang(ReadonlyVariable,Locale):
 
     def get(self):
         return list(sorted(list(set(self.getLangs()) &
-            set(["en_US", "nl_BE", "de_DE","es_ES","fr_FR","it_IT","pl_PL","pt_BR",
+            set(["en_US", "nl_NL", "nl_BE", "de_DE","es_ES","fr_FR","it_IT","pl_PL","pt_BR",
                 "uk_UA","bg_BG","ru_RU","ro_RO","pt_PT"]))))
 
     def humanReadable(self):
